@@ -405,6 +405,10 @@ def delete(request, item_id):
     try:
         post = Post.objects.get(pk=item_id)
         if post.user == request.user:
+            likes = Likes.objects.filter(post_id=post.id)
+            for like in likes:
+                like.delete()
+                
             post.delete()
             return HttpResponse('1')
             
